Requests are specified as one request per line with the following fields:

- `request_id`: the unique request identifier
- `o_lat`: the latitude of the request origin
- `o_lon`: the longitude of the request origin
- `d_lat`: the latitude of the request destination
- `d_lon`: the longitude of the request destination
- `departure_time`: when this request comes into the system
- `passengers`: the number of passengers associated with this request
